@@ -1,6 +1,6 @@
 from rest_framework import serializers
 
-from netbox_storage.api.nested_serializers import NestedFilesystemSerializer
+from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer
 from netbox_storage.models import Drive, Filesystem, LinuxVolume, WindowsVolume
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
@@ -58,6 +58,7 @@ class LinuxVolumeSerializer(serializers.ModelSerializer):
 
 class WindowsVolumeSerializer(serializers.ModelSerializer):
     fs = NestedFilesystemSerializer(required=False, allow_null=True)
+    drives = NestedDriveSerializer(required=False, allow_null=True)
 
     class Meta:
         model = WindowsVolume
@@ -65,6 +66,7 @@ class WindowsVolumeSerializer(serializers.ModelSerializer):
             "id",
             "drive_name",
             "fs",
+            "drives",
             "description",
             "created",
             "last_updated",
