@@ -9,10 +9,10 @@ from netbox.forms import (
     NetBoxModelForm,
 )
 from utilities.forms import (
-    DynamicModelChoiceField,
+    DynamicModelChoiceField, DynamicModelMultipleChoiceField,
 )
 
-from netbox_storage.models import Filesystem, WindowsVolume
+from netbox_storage.models import Filesystem, WindowsVolume, Drive
 
 
 class WindowsVolumeForm(NetBoxModelForm):
@@ -25,6 +25,10 @@ class WindowsVolumeForm(NetBoxModelForm):
         queryset=Filesystem.objects.all(),
         label="Filesystem Name",
     )
+    drives = DynamicModelMultipleChoiceField(
+        queryset=Drive.objects.all(),
+        label="Drives",
+    )
 
     class Meta:
         model = WindowsVolume
@@ -32,6 +36,7 @@ class WindowsVolumeForm(NetBoxModelForm):
         fields = (
             "drive_name",
             "fs",
+            "drives",
             "description",
         )
 
