@@ -99,6 +99,12 @@ class Migration(migrations.Migration):
                 ("fs",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='fs_windows',
                                    to='netbox_storage.filesystem')),
+                (
+                    "drives",
+                    models.ManyToManyField(
+                        blank=True, related_name="drives", to="netbox_storage.drive"
+                    ),
+                ),
                 ("description", models.CharField(max_length=255)),
             ],
             options={
