@@ -51,14 +51,6 @@ class Drive(NetBoxModel):
         super(Drive, self).save(*args, **kwargs)
 
 
-@register_search
-class DriveIndex(SearchIndex):
-    model = Drive
-    fields = (
-        ("size", 200),
-    )
-
-
 class Filesystem(NetBoxModel):
     filesystem = models.CharField(
         unique=True,
@@ -120,17 +112,6 @@ class LinuxVolume(NetBoxModel):
         ordering = ("vg_name", "lv_name", "path")
 
 
-@register_search
-class LinuxVolumeIndex(SearchIndex):
-    model = LinuxVolume
-    fields = (
-        ("vg_name", 100),
-        ("lv_name", 100),
-        ("path", 100),
-        ("fs", 100),
-    )
-
-
 class WindowsVolume(NetBoxModel):
     drive_name = models.CharField(
         max_length=255,
@@ -141,6 +122,11 @@ class WindowsVolume(NetBoxModel):
         related_name="fs_windows",
         verbose_name="Filesystem",
     )
+    drives = models.ManyToManyField(
+        Drive,
+        related_name="drives",
+        verbose_name="Drives",
+    )
     description = models.CharField(
         max_length=255,
         blank=True,
@@ -149,6 +135,7 @@ class WindowsVolume(NetBoxModel):
     clone_fields = [
             "drive_name",
             "fs",
+            "drives",
             "description",
         ]
 
