@@ -1,6 +1,6 @@
 from extras.plugins import PluginTemplateExtension
 
-from netbox_storage.models import Drive
+from netbox_storage.models import Drive, WindowsVolume
 from netbox_storage.tables import RelatedDriveTable
 from dcim.models import Platform
 
@@ -17,6 +17,7 @@ class RelatedDrives(PluginTemplateExtension):
         drive_table = RelatedDriveTable(
             data=drives
         )
+        volumes = WindowsVolume.objects.all()
 
         platform = obj.platform
         if platform.name.__contains__('Windows'):
@@ -24,6 +25,7 @@ class RelatedDrives(PluginTemplateExtension):
                 "netbox_storage/volume/windowsvolume_box.html",
                 extra_context={
                     "drives": drives,
+                    "volumes": volumes
                 },
             )
         else:
